@@ -1,4 +1,4 @@
-use digest::{self, VariableOutput};
+use blake2::digest::{self, VariableOutput};
 
 #[derive(Debug, Clone)]
 pub struct Blake2b256(blake2::VarBlake2b);
@@ -9,23 +9,27 @@ impl Default for Blake2b256 {
     }
 }
 
-impl digest::Input for Blake2b256 {
-    fn input<B: AsRef<[u8]>>(&mut self, data: B) {
-        self.0.input(data)
+impl digest::Update for Blake2b256 {
+    fn update(&mut self, data: impl AsRef<[u8]>) {
+        self.0.update(data)
     }
 }
 
 impl digest::FixedOutput for Blake2b256 {
     type OutputSize = digest::generic_array::typenum::U32;
 
-    fn fixed_result(self) -> digest::generic_array::GenericArray<u8, Self::OutputSize> {
-        let mut out = digest::generic_array::GenericArray::default();
-        self.0.variable_result(|slice| {
+    fn finalize_into(self, out: &mut digest::generic_array::GenericArray<u8, Self::OutputSize>) {
+        self.0.finalize_variable(|slice| {
             assert_eq!(slice.len(), 32);
             out.copy_from_slice(slice)
         });
+    }
 
-        out
+    fn finalize_into_reset(&mut self, out: &mut digest::generic_array::GenericArray<u8, Self::OutputSize>) {
+        self.0.finalize_variable_reset(|slice| {
+            assert_eq!(slice.len(), 32);
+            out.copy_from_slice(slice)
+        });
     }
 }
 
